@@ -16,7 +16,7 @@ void no_comment()
 
     cp = lexbuf;                            /* get first char-address */
 
-    while (cp = strchr(cp, '/'))            /* any slash ? */
+    while ((cp = strchr(cp, '/')))          /* any slash ? */
     {
         if (*(cp + 1) == '/')               /* next one is a slash too: */
         {
