@@ -1,3 +1,6 @@
+#ifndef _INCLUDED_ICRSSDEF_H_
+#define _INCLUDED_ICRSSDEF_H_
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -17,3 +20,5 @@
 #endif
 
 #include "icrss.h"
+
+#endif
